@@ -11,7 +11,7 @@ use Plack::Util::Accessor qw/
     force
 /;
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 sub prepare_app {
     my ($self) = @_;
@@ -68,16 +68,16 @@ sub _add_link {
     for my $lib_path (@{$self->lib}) {
         next if $lib_path eq '.';
         $lib_path =~ s!/!\\!g if $^O eq 'MSWin32';
-        ${$body_ref} =~ s!(\Q$lib_path\E[/\\]+([^\.]+\.[^\s]+)\s+line\s+(\d+))[^<]?!_link_html($1, $2, $3)!eg;
+        ${$body_ref} =~ s!(\Q$lib_path\E[/\\]+([^\.]+\.[^\s]+)\s+line\s+(\d+))[^<]?!$self->_link_html($1, $2, $3)!eg;
     }
 }
 
 sub _link_html {
-    my ($matched, $path, $line_count) = @_;
+    my ($self, $matched, $path, $line_count) = @_;
 
     $path =~ s!\\!/!g; # for win
 
-    return qq|<a href="/source/$path#L$line_count">$matched</a>|;
+    return qq|<a href="|. $self->view_root. qq|/$path#L$line_count">$matched</a>|;
 }
 
 1;
@@ -140,7 +140,7 @@ see more configurations on L<Plack::Middleware::StackTrace>
 
 =begin html
 
-<a href="http://travis-ci.org/bayashi/Plack-Middleware-StackTrace-LinkedSource"><img src="https://secure.travis-ci.org/bayashi/Plack-Middleware-StackTrace-LinkedSource.png?_t=1457861773"/></a> <a href="https://coveralls.io/r/bayashi/Plack-Middleware-StackTrace-LinkedSource"><img src="https://coveralls.io/repos/bayashi/Plack-Middleware-StackTrace-LinkedSource/badge.png?_t=1457861773&branch=master"/></a>
+<a href="http://travis-ci.org/bayashi/Plack-Middleware-StackTrace-LinkedSource"><img src="https://secure.travis-ci.org/bayashi/Plack-Middleware-StackTrace-LinkedSource.png?_t=1460708041"/></a> <a href="https://coveralls.io/r/bayashi/Plack-Middleware-StackTrace-LinkedSource"><img src="https://coveralls.io/repos/bayashi/Plack-Middleware-StackTrace-LinkedSource/badge.png?_t=1460708041&branch=master"/></a>
 
 =end html
 
